@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2015-09-08'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2016-01-23'; # DATE
+our $VERSION = '0.20'; # VERSION
 
 use 5.010001;
 use strict;
@@ -398,20 +398,21 @@ sub _read_file {
 }
 
 sub read_file {
-    my ($self, $filename) = @_;
+    my $self = shift;
+    my $filename = shift;
     $self->_init_read;
     my $res = $self->_push_include_stack($filename);
     die "Can't read '$filename': $res->[1]" unless $res->[0] == 200;
     $res =
-        $self->_read_string($self->_read_file($filename));
+        $self->_read_string($self->_read_file($filename), @_);
     $self->_pop_include_stack;
     $res;
 }
 
 sub read_string {
-    my ($self, $str) = @_;
+    my $self = shift;
     $self->_init_read;
-    $self->_read_string($str);
+    $self->_read_string(@_);
 }
 
 1;
@@ -429,7 +430,61 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.19 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2015-09-08.
+This document describes version 0.20 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-01-23.
+
+=head1 EXPRESSION
+
+=for BEGIN_BLOCK: expression
+
+Expression allows you to do things like:
+
+ [section1]
+ foo=1
+ bar="monkey"
+
+ [section2]
+ baz =!e 1+1
+ qux =!e "grease" . val("section1.bar")
+ quux=!e val("qux") . " " . val('baz')
+
+And the result will be:
+
+ {
+     section1 => {foo=>1, bar=>"monkey"},
+     section2 => {baz=>2, qux=>"greasemonkey", quux=>"greasemonkey 2"},
+ }
+
+For safety, you'll need to set C<enable_expr> attribute to 1 first to enable
+this feature.
+
+The syntax of the expression (the C<expr> encoding) is not officially specified
+yet in the L<IOD> specification. It will probably be Expr (see
+L<Language::Expr::Manual::Syntax>). At the moment, this module implements a very
+limited subset that is compatible (lowest common denominator) with Perl syntax
+and uses C<eval()> to evaluate the expression. However, only the limited subset
+is allowed (checked by Perl 5.10 regular expression).
+
+The supported terms:
+
+ number
+ string (double-quoted and single-quoted)
+ undef literal
+ function call (only the 'val' function is supported)
+ grouping (parenthesis)
+
+The supported operators are:
+
+ + - .
+ * / % x
+ **
+ unary -, unary +, !, ~
+
+The C<val()> function refers to the configuration key. If the argument contains
+".", it will be assumed as C<SECTIONNAME.KEYNAME>, otherwise it will access the
+current section's key. Since parsing is done in a single pass, you can only
+refer to the already mentioned key.
+
+=for END_BLOCK: expression
 
 =head1 ATTRIBUTES
 
@@ -554,60 +609,6 @@ simply be ignored as a regular comment.
 
 =for END_BLOCK: attributes
 
-=head1 EXPRESSION
-
-=for BEGIN_BLOCK: expression
-
-Expression allows you to do things like:
-
- [section1]
- foo=1
- bar="monkey"
-
- [section2]
- baz =!e 1+1
- qux =!e "grease" . val("section1.bar")
- quux=!e val("qux") . " " . val('baz')
-
-And the result will be:
-
- {
-     section1 => {foo=>1, bar=>"monkey"},
-     section2 => {baz=>2, qux=>"greasemonkey", quux=>"greasemonkey 2"},
- }
-
-For safety, you'll need to set C<enable_expr> attribute to 1 first to enable
-this feature.
-
-The syntax of the expression (the C<expr> encoding) is not officially specified
-yet in the L<IOD> specification. It will probably be Expr (see
-L<Language::Expr::Manual::Syntax>). At the moment, this module implements a very
-limited subset that is compatible (lowest common denominator) with Perl syntax
-and uses C<eval()> to evaluate the expression. However, only the limited subset
-is allowed (checked by Perl 5.10 regular expression).
-
-The supported terms:
-
- number
- string (double-quoted and single-quoted)
- undef literal
- function call (only the 'val' function is supported)
- grouping (parenthesis)
-
-The supported operators are:
-
- + - .
- * / % x
- **
- unary -, unary +, !, ~
-
-The C<val()> function refers to the configuration key. If the argument contains
-".", it will be assumed as C<SECTIONNAME.KEYNAME>, otherwise it will access the
-current section's key. Since parsing is done in a single pass, you can only
-refer to the already mentioned key.
-
-=for END_BLOCK: expression
-
 =head1 METHODS
 
 =for BEGIN_BLOCK: methods
@@ -628,7 +629,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Config-IOD-Reader>.
+Source repository is at L<https://github.com/sharyanto/perl-Config-IOD-Reader>.
 
 =head1 BUGS
 
@@ -644,7 +645,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
