@@ -1,7 +1,7 @@
 package Config::IOD::Reader;
 
-our $DATE = '2015-09-08'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2016-01-23'; # DATE
+our $VERSION = '0.20'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,7 +44,7 @@ sub _init_read {
 }
 
 sub _read_string {
-    my ($self, $str) = @_;
+    my ($self, $str, $cb) = @_;
 
     my $res = $self->{_res};
     my $cur_section = $self->{_cur_section};
@@ -53,6 +53,8 @@ sub _read_string {
         qr/^;?\s*!\s*(\w+)\s*/ :
         qr/^;\s*!\s*(\w+)\s*/;
 
+    my $_raw_val; # only to provide to callback
+
     my @lines = split /^/, $str;
     local $self->{_linum} = 0;
   LINE:
@@ -83,6 +85,16 @@ sub _read_string {
             if (!defined($args)) {
                 $self->_err("Invalid arguments syntax '$line'");
             }
+
+            if ($cb) {
+                $cb->(
+                    event => 'directive',
+                    linum=>$self->{_linum}, line=>$line, cur_section=>$self->{_cur_section},
+                    directive => $directive,
+                    args => $args,
+                );
+            }
+
             if ($directive eq 'include') {
                 my $path;
                 if (! @$args) {
@@ -97,7 +109,7 @@ sub _read_string {
                     $self->_err("Can't include '$path': $res->[1]");
                 }
                 $path = $res->[2];
-                $self->_read_string($self->_read_file($path));
+                $self->_read_string($self->_read_file($path, $cb));
                 $self->_pop_include_stack;
             } elsif ($directive eq 'merge') {
                 $self->{_merge} = @$args ? $args : undef;
@@ -115,6 +127,14 @@ sub _read_string {
 
         # comment line
         if ($line =~ /^\s*[;#]/) {
+
+            if ($cb) {
+                $cb->(
+                    event => 'comment',
+                    linum=>$self->{_linum}, line=>$line, cur_section=>$self->{_cur_section},
+                );
+            }
+
             next LINE;
         }
 
@@ -130,6 +150,14 @@ sub _read_string {
                 $self->_merge($prev_section);
             }
 
+            if ($cb) {
+                $cb->(
+                    event => 'section',
+                    linum=>$self->{_linum}, line=>$line, cur_section=>$self->{_cur_section},
+                    section => $cur_section,
+                );
+            }
+
             next LINE;
         }
 
@@ -142,10 +170,12 @@ sub _read_string {
             # quoted/bracketed/braced, so we avoid calling _parse_raw_value here
             # to avoid overhead
             if ($val =~ /\A["!\\[\{]/) {
+                $_raw_val = $val if $cb;
                 my ($err, $parse_res, $decoded_val) = $self->_parse_raw_value($val);
                 $self->_err("Invalid value: " . $err) if $err;
                 $val = $decoded_val;
             } else {
+                $_raw_val = $val if $cb;
                 $val =~ s/\s*[#;].*//; # strip comment
             }
 
@@ -162,6 +192,16 @@ sub _read_string {
                 $res->{$cur_section}{$key} = $val;
             }
 
+            if ($cb) {
+                $cb->(
+                    event => 'key',
+                    linum=>$self->{_linum}, line=>$line, cur_section=>$self->{_cur_section},
+                    key => $key,
+                    val => $val,
+                    raw_val => $_raw_val,
+                );
+            }
+
             next LINE;
         }
 
@@ -190,7 +230,7 @@ Config::IOD::Reader - Read IOD/INI configuration files
 
 =head1 VERSION
 
-This document describes version 0.19 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2015-09-08.
+This document describes version 0.20 of Config::IOD::Reader (from Perl distribution Config-IOD-Reader), released on 2016-01-23.
 
 =head1 SYNOPSIS
 
@@ -392,21 +432,47 @@ simply be ignored as a regular comment.
 
 =head2 new(%attrs) => obj
 
-=head2 $reader->read_file($filename) => hash
+=head2 $reader->read_file($filename[ , $callback ]) => hash
 
 Read IOD configuration from a file. Die on errors.
 
-=head2 $reader->read_string($str) => hash
+See C<read_string> for more information on C<$callback> argument.
+
+=head2 $reader->read_string($str[ , $callback ]) => hash
 
 Read IOD configuration from a string. Die on errors.
 
-=head1 SEE ALSO
+C<$callback> is an optional coderef argument that will be called during various
+stages. It can be useful if you want more information (especially ordering). It
+will be called with hash argument C<%args>
 
-L<IOD> - specification
+=over
 
-L<Config::IOD> - round-trip parser for reading as well as writing IOD documents
+=item * Found a directive line
 
-L<IOD::Examples> - sample documents
+Arguments passed: C<event> (str, has the value of 'directive'), C<linum> (int,
+line number, starts from 1), C<line> (str, raw line), C<directive> (str,
+directive name), C<cur_section> (str, current section name), C<args> (array,
+directive arguments).
+
+=item * Found a comment line
+
+Arguments passed: C<event> (str, 'comment'), C<linum>, C<line>, C<cur_section>.
+
+=item * Found a section line
+
+Arguments passed: C<event> (str, 'section'), C<linum>, C<line>, C<cur_section>,
+C<section> (str, section name).
+
+=item * Found a key line
+
+Arguments passed: C<event> (str, 'section'), C<linum>, C<line>, C<cur_section>,
+C<key> (str, key name), C<val> (any, value name, already decoded if encoded),
+C<raw_val> (str, raw value).
+
+=back
+
+TODO: callback when there is merging.
 
 =head1 HOMEPAGE
 
@@ -414,7 +480,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Config-IOD-Reader>.
+Source repository is at L<https://github.com/sharyanto/perl-Config-IOD-Reader>.
 
 =head1 BUGS
 
@@ -424,13 +490,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<IOD> - specification
+
+L<Config::IOD> - round-trip parser for reading as well as writing IOD documents
+
+L<IOD::Examples> - sample documents
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
